@@ -22,9 +22,10 @@
 #define PHONETIC_LOOKUP_H
 
 
-#include "novel_types.h"
 #include <limits.h>
 #include <math.h>
+#include "novel_types.h"
+#include "pinyin_utils.h"
 #include "phonetic_key_matrix.h"
 #include "ngram.h"
 #include "lookup.h"
@@ -61,11 +62,11 @@ struct trellis_value_t {
     }
 };
 
-template <gint32 nbest>
+template <gint32 nstore>
 static bool inline trellis_value_less_than(const trellis_value_t * item_lhs,
                                            const trellis_value_t * item_rhs) {
 #if 1
-    if (nbest > 1) {
+    if (nstore > 1) {
         /* allow longer sentence */
         if (item_lhs->m_sentence_length + 1 == item_rhs->m_sentence_length &&
             item_lhs->m_poss + LONG_SENTENCE_PENALTY < item_rhs->m_poss)
@@ -138,7 +139,7 @@ struct trellis_constraint_t {
 
 
 /* use maximum heap to get the topest results. */
-template<gint32 nbest>
+template<gint32 nstore>
 bool get_top_results(size_t num,
                      /* out */ GPtrArray * topresults,
                      /* in */ GPtrArray * candidates) {
@@ -152,13 +153,13 @@ bool get_top_results(size_t num,
     trellis_value_t ** end =
         (trellis_value_t **) &g_ptr_array_index(candidates, candidates->len);
 
-    std_lite::make_heap(begin, end, trellis_value_less_than<nbest>);
+    std_lite::make_heap(begin, end, trellis_value_less_than<nstore>);
 
     while (end != begin) {
         trellis_value_t * one = *begin;
         g_ptr_array_add(topresults, one);
 
-        std_lite::pop_heap(begin, end, trellis_value_less_than<nbest>);
+        std_lite::pop_heap(begin, end, trellis_value_less_than<nstore>);
         --end;
 
         if (topresults->len >= num)
@@ -176,7 +177,7 @@ static gint trellis_value_compare(const trellis_value_t ** lhs,
     return -((*lhs)->m_poss - (*rhs)->m_poss);
 }
 
-template <gint32 nbest>
+template <gint32 nstore, gint32 nbest>
 class ForwardPhoneticTrellis {
 private:
     /* Array of LookupStepIndex */
@@ -233,7 +234,7 @@ public:
             /* initialize m_steps_index */
             g_ptr_array_index(m_steps_index, i) = g_hash_table_new(g_direct_hash, g_direct_equal);
             /* initialize m_steps_content */
-            g_ptr_array_index(m_steps_content, i) = g_array_new(FALSE, FALSE, sizeof(trellis_node<nbest>));
+            g_ptr_array_index(m_steps_content, i) = g_array_new(FALSE, FALSE, sizeof(trellis_node<nstore>));
         }
 
         return true;
@@ -249,8 +250,8 @@ public:
             trellis_value_t initial_value(log(1.f));
             initial_value.m_handles[1] = token;
 
-            trellis_node<nbest> initial_node;
-            assert(initial_node.eval_item(&initial_value));
+            trellis_node<nstore> initial_node;
+            check_result(initial_node.eval_item(&initial_value));
 
             LookupStepContent initial_step_content = (LookupStepContent)
                 g_ptr_array_index(m_steps_content, 0);
@@ -279,8 +280,8 @@ public:
             return false;
 
         for (size_t i = 0; i < step->len; ++i) {
-            trellis_node<nbest> * node = &g_array_index
-                (step, trellis_node<nbest>, i);
+            trellis_node<nstore> * node = &g_array_index
+                (step, trellis_node<nstore>, i);
 
             // only initialized in the get_candidates method.
             node->number();
@@ -307,21 +308,21 @@ public:
             (step_index, GUINT_TO_POINTER(token), &key, &value);
 
         if (!lookup_result) {
-            trellis_node<nbest> node;
-            assert(node.eval_item(candidate));
+            trellis_node<nstore> node;
+            check_result(node.eval_item(candidate));
 
             g_array_append_val(step_content, node);
             g_hash_table_insert(step_index, GUINT_TO_POINTER(token), GUINT_TO_POINTER(step_content->len - 1));
             return true;
         } else {
             size_t node_index = GPOINTER_TO_UINT(value);
-            trellis_node<nbest> * node = &g_array_index
-                (step_content, trellis_node<nbest>, node_index);
+            trellis_node<nstore> * node = &g_array_index
+                (step_content, trellis_node<nstore>, node_index);
 
             return node->eval_item(candidate);
         }
 
-        assert(FALSE);
+        abort();
     }
 
     /* get tails */
@@ -331,7 +332,7 @@ public:
 
         GPtrArray * candidates = g_ptr_array_new();
         get_candidates(tail_index, candidates);
-        get_top_results<nbest>(nbest, tails, candidates);
+        get_top_results<nstore>(nbest, tails, candidates);
 
         g_ptr_array_sort(tails, (GCompareFunc)trellis_value_compare);
 
@@ -353,8 +354,8 @@ public:
             return false;
 
         size_t node_index = GPOINTER_TO_UINT(value);
-        trellis_node<nbest> * node = &g_array_index
-            (step_content, trellis_node<nbest>, node_index);
+        trellis_node<nstore> * node = &g_array_index
+            (step_content, trellis_node<nstore>, node_index);
 
         if (sub_index >= node->length())
             return false;
@@ -365,8 +366,8 @@ public:
     }
 };
 
-template <gint32 nbest>
-bool extract_result(const ForwardPhoneticTrellis<nbest> * trellis,
+template <gint32 nstore, gint32 nbest>
+bool extract_result(const ForwardPhoneticTrellis<nstore, nbest> * trellis,
                     const trellis_value_t * tail,
                     /* out */ MatchResult & result) {
     /* reset result */
@@ -388,7 +389,7 @@ bool extract_result(const ForwardPhoneticTrellis<nbest> * trellis,
 
         phrase_token_t last_token = tail->m_handles[0];
         int sub_index = tail->m_sub_index;
-        assert(trellis->get_candidate(index, last_token, sub_index, tail));
+        check_result(trellis->get_candidate(index, last_token, sub_index, tail));
     }
 
     /* no need to reverse the result */
@@ -396,7 +397,7 @@ bool extract_result(const ForwardPhoneticTrellis<nbest> * trellis,
 }
 
 #if 0
-template <gint32 nbest>
+template <gint32 nstore>
 class BackwardPhoneticMatrix {
 private:
     /* Array of matrix_step */
@@ -404,9 +405,9 @@ private:
 
 public:
     /* set tail node */
-    bool set_tail(const matrix_step<nbest> * tail);
+    bool set_tail(const matrix_step<nstore> * tail);
     /* back trace */
-    /* always assume/assert matrix_step.eval_item(...) return true? */
+    /* always assume/check_result matrix_step.eval_item(...) return true? */
     bool back_trace(const ForwardPhoneticTrellis * trellis);
     /* extract results */
     int extract(/* out */ GPtrArray * arrays);
@@ -511,7 +512,7 @@ public:
     }
 };
 
-template <gint32 nbest>
+template <gint32 nstore, gint32 nbest>
 class PhoneticLookup {
 private:
     const gfloat bigram_lambda;
@@ -523,7 +524,7 @@ private:
     SingleGram m_merged_single_gram;
 
 protected:
-    ForwardPhoneticTrellis<nbest> m_trellis;
+    ForwardPhoneticTrellis<nstore, nbest> m_trellis;
 
 protected:
     /* saved varibles */
@@ -546,7 +547,7 @@ protected:
             g_ptr_array_index(topresults, 0);
 
         const trellis_constraint_t * constraint = NULL;
-        assert(m_constraints->get_constraint(start, constraint));
+        check_result(m_constraints->get_constraint(start, constraint));
 
         if (CONSTRAINT_ONESTEP == constraint->m_type) {
             return unigram_gen_next_step(start, constraint->m_constraint_step,
@@ -578,7 +579,7 @@ protected:
                         int start, int end,
                         PhraseIndexRanges ranges) {
         const trellis_constraint_t * constraint = NULL;
-        assert(m_constraints->get_constraint(start, constraint));
+        check_result(m_constraints->get_constraint(start, constraint));
 
         bool found = false;
         BigramPhraseArray bigram_phrase_items = g_array_new
@@ -711,6 +712,8 @@ public:
         : bigram_lambda(lambda),
           unigram_lambda(1. - lambda)
     {
+        assert(nstore <= nbest);
+
         /* store the pointer. */
         m_pinyin_table = pinyin_table;
         m_phrase_index = phrase_index;
@@ -759,13 +762,13 @@ public:
         /* begin the viterbi beam search. */
         for ( int i = 0; i < nstep - 1; ++i ){
             const trellis_constraint_t * cur_constraint = NULL;
-            assert(m_constraints->get_constraint(i, cur_constraint));
+            check_result(m_constraints->get_constraint(i, cur_constraint));
 
             if (CONSTRAINT_NOSEARCH == cur_constraint->m_type)
                 continue;
 
             m_trellis.get_candidates(i, candidates);
-            get_top_results<nbest>(nbeam, topresults, candidates);
+            get_top_results<nstore>(nbeam, topresults, candidates);
 
             if (0 == topresults->len)
                 continue;
@@ -790,7 +793,7 @@ public:
 
             for ( int m = i + 1; m < nstep; ++m ){
                 const trellis_constraint_t * next_constraint = NULL;
-                assert(m_constraints->get_constraint(m, next_constraint));
+                check_result(m_constraints->get_constraint(m, next_constraint));
 
                 if (CONSTRAINT_NOSEARCH == next_constraint->m_type)
                     break;
@@ -828,7 +831,7 @@ public:
             const trellis_value_t * tail = (const trellis_value_t *)
                 g_ptr_array_index(tails, i);
 
-            assert(extract_result<nbest>(&m_trellis, tail, result));
+            check_result(extract_result<nstore>(&m_trellis, tail, result));
             results->add_result(result);
         }
 
@@ -858,7 +861,7 @@ public:
                 continue;
 
             const trellis_constraint_t * constraint = NULL;
-            assert(constraints->get_constraint(i, constraint));
+            check_result(constraints->get_constraint(i, constraint));
 
             if (train_next || CONSTRAINT_ONESTEP == constraint->m_type) {
                 if (CONSTRAINT_ONESTEP == constraint->m_type) {
@@ -878,12 +881,12 @@ public:
                     if (!user) {
                         user = new SingleGram;
                     }
-                    assert(user->get_total_freq(total_freq));
+                    check_result(user->get_total_freq(total_freq));
 
                     guint32 freq = 0;
                     /* compute train factor */
                     if (!user->get_freq(token, freq)) {
-                        assert(user->insert_freq(token, 0));
+                        check_result(user->insert_freq(token, 0));
                         seed = initial_seed;
                     } else {
                         seed = std_lite::max(freq, initial_seed);
@@ -895,10 +898,10 @@ public:
                     if (seed > 0 && total_freq > total_freq + seed)
                         goto next;
 
-                    assert(user->set_total_freq(total_freq + seed));
+                    check_result(user->set_total_freq(total_freq + seed));
                     /* if total_freq is not overflow, then freq won't overflow. */
-                    assert(user->set_freq(token, freq + seed));
-                    assert(m_user_bigram->store(last_token, user));
+                    check_result(user->set_freq(token, freq + seed));
+                    check_result(m_user_bigram->store(last_token, user));
                 next:
                     assert(NULL != user);
                     if (user)
