@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2011 Peng Wu <alexepico@gmail.com>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -28,17 +27,20 @@
 #include "memory_chunk.h"
 #include "pinyin_custom2.h"
 #include "chewing_key.h"
+#include "pinyin_utils.h"
 #include "pinyin_parser2.h"
-#include "pinyin_phrase2.h"
-#include "chewing_large_table.h"
-#include "phrase_large_table2.h"
-#include "facade_chewing_table.h"
-#include "facade_phrase_table2.h"
+#include "zhuyin_parser2.h"
+#include "phonetic_key_matrix.h"
+#include "pinyin_phrase3.h"
+#include "chewing_large_table2.h"
+#include "phrase_large_table3.h"
+#include "facade_chewing_table2.h"
+#include "facade_phrase_table3.h"
 #include "phrase_index.h"
 #include "phrase_index_logger.h"
 #include "ngram.h"
 #include "lookup.h"
-#include "pinyin_lookup2.h"
+#include "phonetic_lookup.h"
 #include "phrase_lookup.h"
 #include "tag_utility.h"
 #include "table_info.h"
