@@ -184,7 +184,7 @@ PhraseLengthIndexLevel2::~PhraseLengthIndexLevel2(){
 	    CASE(15);
 	    CASE(16);
 	default:
-	    assert(false);
+	    abort();
         }
     }
     g_array_free(m_phrase_array_indexes, TRUE);
@@ -228,7 +228,7 @@ int PhraseLengthIndexLevel2::search(int phrase_length,
 	CASE(15);
 	CASE(16);
     default:
-	assert(false);
+	abort();
     }
 #undef CASE
 }
@@ -348,7 +348,7 @@ int PhraseLengthIndexLevel2::add_index(int phrase_length,
 	CASE(15);
         CASE(16);
     default:
-	assert(false);
+	abort();
     }
 
 #undef CASE
@@ -402,7 +402,7 @@ int PhraseLengthIndexLevel2::remove_index(int phrase_length,
 	CASE(15);
 	CASE(16);
     default:
-	assert(false);
+	abort();
     }
 #undef CASE
 }
@@ -472,8 +472,13 @@ bool PhraseLargeTable2::load_text(FILE * infile){
     size_t freq;
 
     while (!feof(infile)) {
+#ifdef __APPLE__
+        int num = fscanf(infile, "%255s %255[^ \t] %u %ld",
+                         pinyin, phrase, &token, &freq);
+#else
         int num = fscanf(infile, "%255s %255s %u %ld",
                          pinyin, phrase, &token, &freq);
+#endif
 
         if (4 != num)
             continue;
@@ -556,7 +561,8 @@ bool PhraseLengthIndexLevel2::load(MemoryChunk * chunk,
                                    table_offset_t offset,
                                    table_offset_t end) {
     char * buf_begin = (char *) chunk->begin();
-    guint32 nindex = *((guint32 *)(buf_begin + offset));
+    guint32 nindex = chunk->get_content<guint32>(offset);
+
     table_offset_t * index = (table_offset_t *)
         (buf_begin + offset + sizeof(guint32));
 
@@ -600,7 +606,7 @@ bool PhraseLengthIndexLevel2::load(MemoryChunk * chunk,
 	    CASE(15);
 	    CASE(16);
 	default:
-	    assert(false);
+	    abort();
         }
 #undef CASE
     }
@@ -656,7 +662,7 @@ bool PhraseLengthIndexLevel2::store(MemoryChunk * new_chunk,
 	    CASE(15);
 	    CASE(16);
 	default:
-	    assert(false);
+	    abort();
         }
         //add '#'
         new_chunk->set_content(offset, &c_separate, sizeof(char));
@@ -776,7 +782,7 @@ bool PhraseLengthIndexLevel2::mask_out(phrase_token_t mask,
 	    CASE(15);
 	    CASE(16);
 	default:
-	    assert(false);
+	    abort();
         }
     }
     /* shrink self array. */
